@@ -1,5 +1,9 @@
-from aylien_model_serving.cached_app_factory import CachedFlaskWrapper
-from .example_serving_handler import process_request
+from aylien_model_serving.cached_app_factory import CachedFlaskAppWrapper
+from .example_serving_handler import predict
+
+
+def process_request():
+    return CachedFlaskAppWrapper.process_json(predict)
 
 
 def run_app():
@@ -11,4 +15,4 @@ def run_app():
         "CACHE_DIR": "./cache",
         "CACHE_DEFAULT_TIMEOUT": 300,
     }
-    return CachedFlaskWrapper.create_app(routes, cache_config)
+    return CachedFlaskAppWrapper.create_app(routes, cache_config)
