@@ -1,4 +1,4 @@
-from aylien_model_serving.cached_app_factory import CachedFlaskWrapper
+from aylien_model_serving.cached_app_factory import CachedFlaskAppWrapper
 import pytest
 import json
 
@@ -13,8 +13,8 @@ def process_response(**kwargs):
 
 @pytest.fixture
 def client():
-    routes = [{"endpoint": "/", "callable": process_request, "methods": ["POST"]}]
-    test_app = CachedFlaskWrapper.create_app(routes)
+    routes = [{"endpoint": "/cached", "callable": process_request_cached, "methods": ["POST"]}]
+    test_app = CachedFlaskAppWrapper.create_app(routes)
     client = test_app.test_client()
 
     return client
@@ -25,15 +25,15 @@ def post_json(client, url, json_dict):
     return client.post(url, data=json.dumps(json_dict), content_type="application/json")
 
 
-def process_request():
-    return CachedFlaskWrapper.process_json(process_response)
+def process_request_cached():
+    return CachedFlaskAppWrapper.process_json(process_response)
 
 
 def test_cache_hit_and_miss(client):
-    post_json(client, "/", {"body": "This is a sentence"})
-    post_json(client, "/", {"body": "This is a sentence"})
+    post_json(client, "/cached", {"body": "This is a sentence"})
+    post_json(client, "/cached", {"body": "This is a sentence"})
     assert 1 == counter  # cache hit
-    client.post("/", json={"index_id": "", "query": "I am shark"})
+    client.post("/cached", json={"index_id": "", "query": "I am shark"})
     assert 2 == counter  # cache miss
 
 
